==> blancoMessage-0.5.3-src.zip: blancoMessage/blanco.ruby/main/blanco/message/message/BlancoMessageMessage.rb <==
#
# ̃\[XR[h blanco FrameworkɂĎĂ܂B
#

#
# blancoMessageIɗp郁bZ[WNXłB
#
class BlancoMessageMessage

    #
    # [bZ[W`ID[{0}]̃pbP[Ww肳Ă܂B]
    #
    # No.2:
    #
    MBMSGI01 = '[MBMSGI01] bZ[W`ID[{0}]̃pbP[Ww肳Ă܂B'

    #
    # [T|[gȂo̓vO~Oꏈn[{0}]w肳܂B]
    #
    # No.3:
    #
    MBMSGI02 = '[MBMSGI02] T|[gȂo̓vO~Oꏈn[{0}]w肳܂B'

    #
    # [bZ[W`ID[{0}]ɂāAL[[{1}]2ȏ゠܂BL[2ȏw肷邱Ƃ͂ł܂B]
    #
    # No.4:
    #
    MBMSGI03 = '[MBMSGI03] bZ[W`ID[{0}]ɂāAL[[{1}]2ȏ゠܂BL[2ȏw肷邱Ƃ͂ł܂B'

    #
    # [bZ[W`ID[{0}]ɂāAL[[{1}]̃bZ[WsłBbZ[W`ƂĔfꍇ̒ǔ[{2}]ƃ\[XohƂĔfꍇ̒ǔ[{3}]ƂقȂ܂Bu̔ԍ͔ł܂Ă܂񂩁HtH[}bg`ĂB]
    #
    # No.5:
    #
    MBMSGI04 = '[MBMSGI04] bZ[W`ID[{0}]ɂāAL[[{1}]̃bZ[WsłBbZ[W`ƂĔfꍇ̒ǔ[{2}]ƃ\[XohƂĔfꍇ̒ǔ[{3}]ƂقȂ܂Bu̔ԍ͔ł܂Ă܂񂩁HtH[}bg`ĂB'

    #
    # [^fBNg[{0}]݂܂B]
    #
    # No.8:
    #
    MBMSGA01 = '[MBMSGA01] ^fBNg[{0}]݂܂B'

    #
    # bZ[W`ID[BlancoMessage]AL[[MBMSGI01]̕擾܂B
    #
    # No.2:
    # [bZ[W`ID[{0}]̃pbP[Ww肳Ă܂B]
    #
    # param arg0 u{0}̒lB
    # return bZ[WB
    #
    def getMbmsgi01(arg0)
        if arg0.nil?
            raise ArgumentError, "\bh[getMbmsgi01]̃p[^[arg0]nil^܂BÃp[^nil^邱Ƃ͂ł܂"
        end

        return '[MBMSGI01] bZ[W`ID[' + arg0 + ']̃pbP[Ww肳Ă܂B'
    end

    #
    # bZ[W`ID[BlancoMessage]AL[[MBMSGI02]̕擾܂B
    #
    # No.3:
    # [T|[gȂo̓vO~Oꏈn[{0}]w肳܂B]
    #
    # param arg0 u{0}̒lB
    # return bZ[WB
    #
    def getMbmsgi02(arg0)
        if arg0.nil?
            raise ArgumentError, "\bh[getMbmsgi02]̃p[^[arg0]nil^܂BÃp[^nil^邱Ƃ͂ł܂"
        end

        return '[MBMSGI02] T|[gȂo̓vO~Oꏈn[' + arg0 + ']w肳܂B'
    end

    #
    # bZ[W`ID[BlancoMessage]AL[[MBMSGI03]̕擾܂B
    #
    # No.4:
    # [bZ[W`ID[{0}]ɂāAL[[{1}]2ȏ゠܂BL[2ȏw肷邱Ƃ͂ł܂B]
    #
    # param arg0 u{0}̒lB
    # param arg1 u{1}̒lB
    # return bZ[WB
    #
    def getMbmsgi03(arg0, arg1)
        if arg0.nil?
            raise ArgumentError, "\bh[getMbmsgi03]̃p[^[arg0]nil^܂BÃp[^nil^邱Ƃ͂ł܂"
        end
        if arg1.nil?
            raise ArgumentError, "\bh[getMbmsgi03]̃p[^[arg1]nil^܂BÃp[^nil^邱Ƃ͂ł܂"
        end

        return '[MBMSGI03] bZ[W`ID[' + arg0 + ']ɂāAL[[' + arg1 + ']2ȏ゠܂BL[2ȏw肷邱Ƃ͂ł܂B'
    end

    #
    # bZ[W`ID[BlancoMessage]AL[[MBMSGI04]̕擾܂B
    #
    # No.5:
    # [bZ[W`ID[{0}]ɂāAL[[{1}]̃bZ[WsłBbZ[W`ƂĔfꍇ̒ǔ[{2}]ƃ\[XohƂĔfꍇ̒ǔ[{3}]ƂقȂ܂Bu̔ԍ͔ł܂Ă܂񂩁HtH[}bg`ĂB]
    #
    # param arg0 u{0}̒lB
    # param arg1 u{1}̒lB
    # param arg2 u{2}̒lB
    # param arg3 u{3}̒lB
    # return bZ[WB
    #
    def getMbmsgi04(arg0, arg1, arg2, arg3)
        if arg0.nil?
            raise ArgumentError, "\bh[getMbmsgi04]̃p[^[arg0]nil^܂BÃp[^nil^邱Ƃ͂ł܂"
        end
        if arg1.nil?
            raise ArgumentError, "\bh[getMbmsgi04]̃p[^[arg1]nil^܂BÃp[^nil^邱Ƃ͂ł܂"
        end
        if arg2.nil?
            raise ArgumentError, "\bh[getMbmsgi04]̃p[^[arg2]nil^܂BÃp[^nil^邱Ƃ͂ł܂"
        end
        if arg3.nil?
            raise ArgumentError, "\bh[getMbmsgi04]̃p[^[arg3]nil^܂BÃp[^nil^邱Ƃ͂ł܂"
        end

        return '[MBMSGI04] bZ[W`ID[' + arg0 + ']ɂāAL[[' + arg1 + ']̃bZ[WsłBbZ[W`ƂĔfꍇ̒ǔ[' + arg2 + ']ƃ\[XohƂĔfꍇ̒ǔ[' + arg3 + ']ƂقȂ܂Bu̔ԍ͔ł܂Ă܂񂩁HtH[}bg`ĂB'
    end

    #
    # bZ[W`ID[BlancoMessage]AL[[MBMSGA01]̕擾܂B
    #
    # No.8:
    # [^fBNg[{0}]݂܂B]
    #
    # param arg0 u{0}̒lB
    # return bZ[WB
    #
    def getMbmsga01(arg0)
        if arg0.nil?
            raise ArgumentError, "\bh[getMbmsga01]̃p[^[arg0]nil^܂BÃp[^nil^邱Ƃ͂ł܂"
        end

        return '[MBMSGA01] ^fBNg[' + arg0 + ']݂܂B'
    end
end

==> blancoMessage-0.6.3-src.zip: blancoMessage/blanco.ruby/main/blanco/message/message/BlancoMessageMessage.rb <==
#
# ̃\[XR[h blanco FrameworkɂĎĂ܂B
#

#
# blancoMessageIɗp郁bZ[WNXłB
#
class BlancoMessageMessage

    #
    # [bZ[W`ID[{0}]̃pbP[Ww肳Ă܂B]
    #
    # No.2:
    #
    MBMSGI01 = '[MBMSGI01] bZ[W`ID[{0}]̃pbP[Ww肳Ă܂B'

    #
    # L[l: KEY_MBMSGI01
    #
    # No.2:
    #
    KEY_MBMSGI01 = 'MBMSGI01'

    #
    # [T|[gȂo̓vO~Oꏈn[{0}]w肳܂B]
    #
    # No.3:
    #
    MBMSGI02 = '[MBMSGI02] T|[gȂo̓vO~Oꏈn[{0}]w肳܂B'

    #
    # L[l: KEY_MBMSGI02
    #
    # No.3:
    #
    KEY_MBMSGI02 = 'MBMSGI02'

    #
    # [bZ[W`ID[{0}]ɂāAL[[{1}]2ȏ゠܂BL[2ȏw肷邱Ƃ͂ł܂B]
    #
    # No.4:
    #
    MBMSGI03 = '[MBMSGI03] bZ[W`ID[{0}]ɂāAL[[{1}]2ȏ゠܂BL[2ȏw肷邱Ƃ͂ł܂B'

    #
    # L[l: KEY_MBMSGI03
    #
    # No.4:
    #
    KEY_MBMSGI03 = 'MBMSGI03'

    #
    # [bZ[W`ID[{0}]ɂāAL[[{1}]̃bZ[WsłBbZ[W`ƂĔfꍇ̒ǔ[{2}]ƃ\[XohƂĔfꍇ̒ǔ[{3}]ƂقȂ܂Bu̔ԍ͔ł܂Ă܂񂩁HtH[}bg`ĂB]
    #
    # No.5:
    #
    MBMSGI04 = '[MBMSGI04] bZ[W`ID[{0}]ɂāAL[[{1}]̃bZ[WsłBbZ[W`ƂĔfꍇ̒ǔ[{2}]ƃ\[XohƂĔfꍇ̒ǔ[{3}]ƂقȂ܂Bu̔ԍ͔ł܂Ă܂񂩁HtH[}bg`ĂB'

    #
    # L[l: KEY_MBMSGI04
    #
    # No.5:
    #
    KEY_MBMSGI04 = 'MBMSGI04'

    #
    # [^fBNg[{0}]݂܂B]
    #
    # No.8:
    #
    MBMSGA01 = '[MBMSGA01] ^fBNg[{0}]݂܂B'

    #
    # L[l: KEY_MBMSGA01
    #
    # No.8:
    #
    KEY_MBMSGA01 = 'MBMSGA01'

    #
    # bZ[W`ID[BlancoMessage]AL[[MBMSGI01]̕擾܂B
    #
    # No.2:
    # [bZ[W`ID[{0}]̃pbP[Ww肳Ă܂B]
    #
    # param arg0 u{0}̒lB
    # return bZ[WB
    #
    def getMbmsgi01(arg0)
        if arg0.nil?
            raise ArgumentError, "\bh[getMbmsgi01]̃p[^[arg0]nil^܂BÃp[^nil^邱Ƃ͂ł܂"
        end

        return '[MBMSGI01] bZ[W`ID[' + arg0 + ']̃pbP[Ww肳Ă܂B'
    end

    #
    # bZ[W`ID[BlancoMessage]AL[[MBMSGI02]̕擾܂B
    #
    # No.3:
    # [T|[gȂo̓vO~Oꏈn[{0}]w肳܂B]
    #
    # param arg0 u{0}̒lB
    # return bZ[WB
    #
    def getMbmsgi02(arg0)
        if arg0.nil?
            raise ArgumentError, "\bh[getMbmsgi02]̃p[^[arg0]nil^܂BÃp[^nil^邱Ƃ͂ł܂"
        end

        return '[MBMSGI02] T|[gȂo̓vO~Oꏈn[' + arg0 + ']w肳܂B'
    end

    #
    # bZ[W`ID[BlancoMessage]AL[[MBMSGI03]̕擾܂B
    #
    # No.4:
    # [bZ[W`ID[{0}]ɂāAL[[{1}]2ȏ゠܂BL[2ȏw肷邱Ƃ͂ł܂B]
    #
    # param arg0 u{0}̒lB
    # param arg1 u{1}̒lB
    # return bZ[WB
    #
    def getMbmsgi03(arg0, arg1)
        if arg0.nil?
            raise ArgumentError, "\bh[getMbmsgi03]̃p[^[arg0]nil^܂BÃp[^nil^邱Ƃ͂ł܂"
        end
        if arg1.nil?
            raise ArgumentError, "\bh[getMbmsgi03]̃p[^[arg1]nil^܂BÃp[^nil^邱Ƃ͂ł܂"
        end

        return '[MBMSGI03] bZ[W`ID[' + arg0 + ']ɂāAL[[' + arg1 + ']2ȏ゠܂BL[2ȏw肷邱Ƃ͂ł܂B'
    end

    #
    # bZ[W`ID[BlancoMessage]AL[[MBMSGI04]̕擾܂B
    #
    # No.5:
    # [bZ[W`ID[{0}]ɂāAL[[{1}]̃bZ[WsłBbZ[W`ƂĔfꍇ̒ǔ[{2}]ƃ\[XohƂĔfꍇ̒ǔ[{3}]ƂقȂ܂Bu̔ԍ͔ł܂Ă܂񂩁HtH[}bg`ĂB]
    #
    # param arg0 u{0}̒lB
    # param arg1 u{1}̒lB
    # param arg2 u{2}̒lB
    # param arg3 u{3}̒lB
    # return bZ[WB
    #
    def getMbmsgi04(arg0, arg1, arg2, arg3)
        if arg0.nil?
            raise ArgumentError, "\bh[getMbmsgi04]̃p[^[arg0]nil^܂BÃp[^nil^邱Ƃ͂ł܂"
        end
        if arg1.nil?
            raise ArgumentError, "\bh[getMbmsgi04]̃p[^[arg1]nil^܂BÃp[^nil^邱Ƃ͂ł܂"
        end
        if arg2.nil?
            raise ArgumentError, "\bh[getMbmsgi04]̃p[^[arg2]nil^܂BÃp[^nil^邱Ƃ͂ł܂"
        end
        if arg3.nil?
            raise ArgumentError, "\bh[getMbmsgi04]̃p[^[arg3]nil^܂BÃp[^nil^邱Ƃ͂ł܂"
        end

        return '[MBMSGI04] bZ[W`ID[' + arg0 + ']ɂāAL[[' + arg1 + ']̃bZ[WsłBbZ[W`ƂĔfꍇ̒ǔ[' + arg2 + ']ƃ\[XohƂĔfꍇ̒ǔ[' + arg3 + ']ƂقȂ܂Bu̔ԍ͔ł܂Ă܂񂩁HtH[}bg`ĂB'
    end

    #
    # bZ[W`ID[BlancoMessage]AL[[MBMSGA01]̕擾܂B
    #
    # No.8:
    # [^fBNg[{0}]݂܂B]
    #
    # param arg0 u{0}̒lB
    # return bZ[WB
    #
    def getMbmsga01(arg0)
        if arg0.nil?
            raise ArgumentError, "\bh[getMbmsga01]̃p[^[arg0]nil^܂BÃp[^nil^邱Ƃ͂ł܂"
        end

        return '[MBMSGA01] ^fBNg[' + arg0 + ']݂܂B'
    end
end
